package Bundle::SDK::SIMON;

$VERSION = '1.02';

1;

__END__

=head1 NAME

Bundle::SDK::SIMON - CPAN Bundle for '10 Modules I Wouldn't Go Anywhere Without'

=head1 SYNOPSIS

C<perl -MCPANPLUS -e 'install Bundle::SDK::SIMON'>

=head1 CONTENTS

Bundle::CPAN undef

Bundle::LWP undef

Mail::Send undef

MLDBM undef

Date::Calc undef

DBI undef

Data::Dumper undef

POE undef

File::Spec undef

XML::Simple undef

=head1 DESCRIPTION

This bundle installs the 10 modules outlined in my popular "10 Modules I
Wouldn't Go Anywhere Without" talk, given at TPC 5 and YAPC 2002. I'd
highly recommend people who are beginning to use Perl modules to start
with this essential set, which I consider to be a reasonable "Perl SDK".

The talk notes are included in this distribution as F<modules.pod>

=head1 AUTHOR

Simon Cozens, C<simon@cpan.org>.

Maintained by Alberto Simões C<ambs@cpan.org>.

=cut
